@@ -1,3 +1,5 @@
+from datetime import date
+
 from marshmallow import Schema, fields, validate, ValidationError, validates_schema, INCLUDE
 
 
@@ -34,6 +36,7 @@ def create_pipeline_settings_schema(pipeline_settings_schema_data):
             "datetime": fields.DateTime,
             "array": fields.List,
             "object": fields.Nested,
+            "date": fields.Date,
         }.get(data_type)
 
         if not field_type:
@@ -50,6 +53,7 @@ def create_pipeline_settings_schema(pipeline_settings_schema_data):
                 "float": fields.Float,
                 "boolean": fields.Boolean,
                 "datetime": fields.DateTime,
+                "date": fields.Date,
             }.get(element_type)
             if not field_args["cls_or_instance"]:
                 raise ValidationError(
@@ -119,6 +123,7 @@ def create_pipeline_settings_schema(pipeline_settings_schema_data):
             "float": fields.Float,
             "boolean": fields.Boolean,
             "datetime": fields.DateTime,
+            "date": fields.Date,
             "array": fields.List,
             "object": fields.Nested,
         }.get(data_type)
@@ -137,6 +142,7 @@ def create_pipeline_settings_schema(pipeline_settings_schema_data):
                 "float": fields.Float,
                 "boolean": fields.Boolean,
                 "datetime": fields.DateTime,
+                "date": fields.Date,
             }.get(element_type)
             if not field_args["cls_or_instance"]:
                 raise ValidationError(
@@ -229,7 +235,7 @@ class SettingSchema(Schema):
     dataType = fields.String(
         required=True,
         validate=validate.OneOf(
-            ["string", "int", "float", "boolean", "datetime", "array", "object"]
+            ["string", "int", "float", "boolean", "datetime", "array", "object", "date"]
         ),
         metadata={"description": "The underlying data type of the setting"},
     )
@@ -317,6 +323,13 @@ class SettingSchema(Schema):
                     raise ValidationError(
                         f"Option value `{value}` must be an ISO 8601 string for `datetime`."
                     )
+                elif data_type == "date":
+                    try:
+                        date.fromisoformat(value)
+                    except Exception:
+                        raise ValidationError(
+                            f"Option value `{value}` must be an ISO 8601 string for `date`."
+                        )
 
     @validates_schema
     def validate_search_endpoint(self, data, **kwargs):
