@@ -54,6 +54,8 @@ import yaml
 from yaml.loader import SafeLoader
 from marshmallow import Schema, fields, pre_load, EXCLUDE, INCLUDE, validates_schema
 from marshmallow.exceptions import ValidationError
+
+from pypeline.executable_job_config_schema import ExecutableJobSchema
 from pypeline.utils.module_utils import PypelineModuleLoader, normalized_pkg_name
 from pypeline.constants import PYPELINE_YAML_PATH, PYPELINE_CLIENT_PKG_NAME
 from pypeline.pipeline_config_schema import BasePipelineSchema
@@ -165,6 +167,14 @@ class PypelineYamlSchema(ExcludeUnknownSchema):
         required=False,
     )
 
+    executableJobs = fields.Dict(
+        keys=fields.String(),
+        values=fields.Nested(ExecutableJobSchema),
+        description="List of executable jobs",
+        required=False,
+        allow_none=True,
+    )
+
     def validate_errors(self, schema: Schema, value: dict):
         """Run Marshmallow validate() and raise if any errors"""
         schema = schema()
