@@ -41,6 +41,16 @@ def retrieve_latest_schedule_config():
     return None
 
 
+def retrieve_executable_job_config():
+    pypeline_config = load_pypeline_config()
+    if "executableJobs" in pypeline_config:
+        tasks = []
+        for task_id, config in pypeline_config["executableJobs"].items():
+            tasks.append(config)
+        return tasks
+    return None
+
+
 def get_service_config_for_worker(
     pypeline_config: dict, worker_name: str = None
 ) -> Union[dict, None]:
